<?php
/**
 * @author    sh1zen
 * @copyright Copyright (C)  2021
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 */

namespace FlexySEO\Engine\Generators\Templates;

use FlexySEO\core\Settings;
use FlexySEO\Engine\Generators\OpenGraph;
use FlexySEO\Engine\Generators\TwitterCard;
use FlexySEO\Engine\Helpers\Current_Page_Helper;

class TermArchive_Generator extends \FlexySEO\Engine\Generator
{
    /**
     * @param Current_Page_Helper $current_page
     */
    public function __construct($current_page)
    {
        parent::__construct($current_page);

        $type = $this->current_page->get_queried_object()->taxonomy;

        if (!$type)
            $this->settings_path = 'none';

        $this->settings_path = "seo.tax.{$type}.";
    }

    /**
     * Generates the robots value.
     *
     * @param array $robots
     * @return array The robots value.
     */
    public function get_robots($robots = [])
    {
        $robots = [
            'index'             => 'noindex',
            'follow'            => 'follow',
            'max-snippet'       => 'max-snippet:-1',
            'max-image-preview' => 'max-image-preview:large',
        ];

        if (Settings::get($this->settings_path . 'show', true)) {
            $robots['index'] = 'index';
        }

        return $robots;
    }

    /**
     * Generates the meta keywords.
     *
     * @param string $keywords
     * @return string The meta keywords.
     */
    public function get_keywords($keywords = '')
    {
        return parent::get_keywords(Settings::get($this->settings_path . 'keywords', ''));
    }

    /**
     * Generates the title structure.
     *
     * @param string $title
     * @return string The title.
     */
    public function generate_title($title = '')
    {
        return parent::generate_title(Settings::get($this->settings_path . 'title', '%%title%%'));
    }

    /**
     * @return OpenGraph
     */
    public function openGraph()
    {
        $og = parent::openGraph();

        $og->type('website');

        return $og;
    }

    /**
     * @return TwitterCard
     */
    public function twitterCard()
    {
        return parent::twitterCard();
    }

    /**
     * Generates the title structure.
     *
     * @param string $description
     * @return string The meta description.
     */
    public function get_description($description = '')
    {
        return parent::get_description(Settings::get($this->settings_path . 'meta_desc', ''));
    }

}